pub struct BlockTable {
pub physical_blocks: SmallVec<[BlockId; 8]>,
pub logical_to_physical: SmallVec<[u32; 8]>,
pub sequence_length: usize,
pub block_size: usize,
}Expand description
Block table for mapping logical to physical cache blocks
Fields
physical_blocks: SmallVec<[BlockId; 8]>Physical block IDs allocated for this sequence
logical_to_physical: SmallVec<[u32; 8]>Mapping from logical to physical block indices
sequence_length: usizeCurrent sequence length in tokens
block_size: usizeBlock size (tokens per block)
Implementations
Sourceimpl BlockTable
impl BlockTable
Sourcepub fn num_blocks(&self) -> usize
pub fn num_blocks(&self) -> usize
Get number of blocks allocated
Sourcepub fn blocks_needed_for_length(length: usize, block_size: usize) -> usize
pub fn blocks_needed_for_length(length: usize, block_size: usize) -> usize
Get required number of blocks for sequence length
Sourcepub fn has_free_space(&self) -> bool
pub fn has_free_space(&self) -> bool
Check if can accommodate more tokens without new blocks
Sourcepub fn free_tokens(&self) -> usize
pub fn free_tokens(&self) -> usize
Get number of free tokens in allocated blocks
Sourcepub fn add_blocks(&mut self, blocks: &[BlockId])
pub fn add_blocks(&mut self, blocks: &[BlockId])
Add blocks to the table
Sourcepub fn extend_sequence(&mut self, additional_tokens: usize) -> Result<()>
pub fn extend_sequence(&mut self, additional_tokens: usize) -> Result<()>
Extend sequence length