pub enum ExecutorExecutionDeferral {
Capacity(ExecutorExecutionCapacityDeferral),
RequestState(ExecutorRequestStateDeferral),
}Expand description
A pre-submit execution frontier can be blocked by independently evolving sources. Capacity waits participate in scheduler pressure/yield policy; Request-state waits never do and resume only from their exact hazard coordinator.
Variants
Capacity(ExecutorExecutionCapacityDeferral)
RequestState(ExecutorRequestStateDeferral)
Implementations
Sourceimpl ExecutorExecutionDeferral
impl ExecutorExecutionDeferral
pub const fn stage(&self) -> ExecutorExecutionCapacityStage
pub const fn as_capacity(&self) -> Option<&ExecutorExecutionCapacityDeferral>
pub const fn as_request_state(&self) -> Option<&ExecutorRequestStateDeferral>