pub struct ExecutorExecutionMaintenanceMutation { /* private fields */ }Expand description
One exact physical pool mutation completed while an executor was trying to make an unsubmitted frontier runnable.
Implementations
Sourceimpl ExecutorExecutionMaintenanceMutation
impl ExecutorExecutionMaintenanceMutation
pub fn pool_id(&self) -> &DynamicBackingPoolId
pub const fn domain_id(&self) -> CapacityDomainId
pub fn chunk(&self) -> &BackingChunkIdentity
pub const fn chunk_bytes(&self) -> u64
pub const fn published_capacity_bytes(&self) -> u64
pub const fn capacity_epoch(&self) -> u64