pub struct ExecutorPrefillMaintenanceDeferral { /* private fields */ }Expand description
Non-authoritative projection of plan-runtime maintenance work.
The request id is the only handle returned to the engine. Implementations
must retain the sealed deferral internally and validate it again when
ModelExecutor::maintain_prefill_backing is called.
Implementations
Sourceimpl ExecutorPrefillMaintenanceDeferral
impl ExecutorPrefillMaintenanceDeferral
pub fn new( request_id: RequestId, observed: ExecutorAdmissionEpochs, wait_condition: CapacityWaitCondition, stage: ExecutorPrefillMaintenanceStage, blockers: Vec<ExecutorPrefillMaintenanceBlocker>, ) -> Result<Self>
pub fn from_admission( request_id: &RequestId, deferred: &AdmissionDeferred, ) -> Result<Self>
pub fn from_backing( request_id: &RequestId, deferred: &DynamicBackingDeferred, ) -> Result<Self>
pub fn request_id(&self) -> &RequestId
pub const fn observed(&self) -> ExecutorAdmissionEpochs
pub fn wait_condition(&self) -> &CapacityWaitCondition
pub const fn stage(&self) -> ExecutorPrefillMaintenanceStage
pub fn blockers(&self) -> &[ExecutorPrefillMaintenanceBlocker]