TokenId

Struct TokenId 

pub struct TokenId(pub u32);
Token identifier used across the inference pipeline.

This is a thin newtype wrapper around u32 so that we retain the ergonomic .0 access pattern while being able to provide convenience constructors the rest of the refactor relies on (e.g. TokenId::new, TokenId::MAX).

Tuple Fields

0: u32

Implementations

Source

impl TokenId

pub const MAX: TokenId

pub const fn new(value: u32) -> TokenId

pub const fn get(self) -> u32