pub enum NumericalExecutionPolicy {
Auto,
Require(NumericalProfileId),
}Expand description
A request, never proof that a numerical profile can execute on a device.
Require must fail if its complete declared program cannot be supported.
Variants
Auto
Require(NumericalProfileId)