pub enum ProfilePhase {
Load,
Prepare,
Forward,
Prefill,
Decode,
Transfer,
Synchronize,
}Variants
Load
Prepare
Forward
Backend operation shared by prefill and decode. The exact request phase is derived from the bound work shape rather than changing operation identity or selecting another provider in the hot path.
Prefill
Decode
Transfer
Synchronize