pub enum ResolutionField {
Show 20 variants
OriginalSources,
ResolvedSources,
Config,
ExternalMetadata,
Family,
WeightSchema,
WeightFormat,
Tokenizer,
Template,
SpecialTokens,
Device,
Capabilities,
RuntimePreset,
RuntimeMemory,
Admission,
Engine,
ExecutionPlan,
Sampling,
Stop,
StructuredOutput,
}Variants
OriginalSources
ResolvedSources
Config
ExternalMetadata
Family
WeightSchema
WeightFormat
Tokenizer
Template
SpecialTokens
Device
Capabilities
RuntimePreset
RuntimeMemory
Admission
Engine
ExecutionPlan
Sampling
Stop
StructuredOutput
Implementations
Sourceimpl ResolutionField
impl ResolutionField
pub const fn as_str(self) -> &'static str
Sourcepub const fn accepts_source(self, source: ResolutionDecisionSource) -> bool
pub const fn accepts_source(self, source: ResolutionDecisionSource) -> bool
Returns whether a provenance source is allowed to author this decision. This matrix prevents a self-consistent package from relabeling a planner, model, or capability decision as a generic product default.