pub enum ResolutionSourceProvenance {
LockedModelFile {
source_role: ModelArtifactSourceRole,
relative_path: String,
},
Upstream {
producer_id: String,
producer_version: ContractVersion,
producer_implementation_fingerprint: ResolutionFingerprint,
revision: String,
artifact_locator: String,
},
}Expand description
Externally anchored origin of resolution source bytes. A source is either one exact file from the locked model snapshot or an explicitly identified upstream producer. There is no unstructured locator variant.
Variants
LockedModelFile
Upstream
Implementations