pub enum StepResourceSlotKind {
Dedicated,
OrderedSingleFenceStepWave,
}Variants
Dedicated
OrderedSingleFenceStepWave
Every member is an internal activation and the runtime must submit the canonical plan order as one ordered command batch with one terminal fence before it may consume this reuse proof.