pub struct ActiveSequenceCompletionReceipt { /* private fields */ }Expand description
Core-signed evidence that synchronization succeeded and the exact active slot epoch was atomically cleared. It is trusted output and deliberately cannot be deserialized or constructed by a caller.
Implementations
Sourceimpl ActiveSequenceCompletionReceipt
impl ActiveSequenceCompletionReceipt
pub fn plan(&self) -> &TrustedPlanRuntimeEvidence
pub fn run_id(&self) -> &RunId
pub fn request_id(&self) -> &RequestIdentity
pub const fn activation_epoch(&self) -> u64
pub fn runtime_implementation_fingerprint(&self) -> &str