pub struct CheckpointTimingSnapshot {
pub capture: CheckpointOperationTimings,
pub restore: CheckpointOperationTimings,
pub cache: CheckpointCacheTimings,
}Expand description
Host phase totals may overlap (notably abandoned recovery and the native phases it invokes). They must not be summed with device execution time.
Fields
capture: CheckpointOperationTimingsrestore: CheckpointOperationTimingscache: CheckpointCacheTimingsTrait Implementations
Sourceimpl Clone for CheckpointTimingSnapshot
impl Clone for CheckpointTimingSnapshot
Sourcefn clone(&self) -> CheckpointTimingSnapshot
fn clone(&self) -> CheckpointTimingSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CheckpointTimingSnapshot
Sourceimpl Debug for CheckpointTimingSnapshot
impl Debug for CheckpointTimingSnapshot
Sourceimpl Default for CheckpointTimingSnapshot
impl Default for CheckpointTimingSnapshot
Sourcefn default() -> CheckpointTimingSnapshot
fn default() -> CheckpointTimingSnapshot
Returns the “default value” for a type. Read more
impl Eq for CheckpointTimingSnapshot
Sourceimpl PartialEq for CheckpointTimingSnapshot
impl PartialEq for CheckpointTimingSnapshot
Sourceimpl Serialize for CheckpointTimingSnapshot
impl Serialize for CheckpointTimingSnapshot
impl StructuralPartialEq for CheckpointTimingSnapshot