pub struct DeviceCommandExecutionTiming { /* private fields */ }Expand description
Backend-counter timing for one command entry in a core-owned submission. A command may own multiple physical encoder intervals, for example a gather-compute-scatter implementation.
Implementations
Sourceimpl DeviceCommandExecutionTiming
impl DeviceCommandExecutionTiming
pub fn new( command_index: u32, intervals: Vec<DeviceExecutionInterval>, ) -> Option<Self>
pub const fn command_index(&self) -> u32
pub fn intervals(&self) -> &[DeviceExecutionInterval]
pub fn elapsed_ns(&self) -> u64