DeviceReusableExecutionPreparation

Struct DeviceReusableExecutionPreparation 

pub struct DeviceReusableExecutionPreparation { /* private fields */ }
Backend receipt for the explicit configure -> prepare -> seal lifecycle.

Captures happen only between Preparing and Ready. Once sealed, a backend must replay a resident executable or use eager execution; it must not compile new work on a product request.

Implementations

Source

impl DeviceReusableExecutionPreparation

pub const fn unsupported() -> Self

pub fn preparing(plan: DeviceReusableExecutionPlan) -> Self

pub fn preparing_with_progress( plan: DeviceReusableExecutionPlan, resident_executables: usize, rejected_executables: usize, captured_executables: u64, uploaded_executables: u64, capacity_deferred_executables: u64, ) -> Result<Self, VNextError>

pub fn ready( plan: DeviceReusableExecutionPlan, resident_executables: usize, rejected_executables: usize, captured_executables: u64, uploaded_executables: u64, capacity_deferred_executables: u64, ) -> Result<Self, VNextError>

pub const fn state(self) -> DeviceReusableExecutionPreparationState

pub const fn maximum_executables(self) -> u64

pub const fn resident_executables(self) -> u64

pub const fn rejected_executables(self) -> u64

pub const fn captured_executables(self) -> u64

pub const fn uploaded_executables(self) -> u64

pub const fn capacity_deferred_executables(self) -> u64