pub struct DynamicPoolMaintenanceBoundaryPool { /* private fields */ }Expand description
Event-bound physical and logical state for one pool at a failed device reservation. Consumers can recompute the complete reclaim frontier instead of inferring it from a later health snapshot.
Implementations
Sourceimpl DynamicPoolMaintenanceBoundaryPool
impl DynamicPoolMaintenanceBoundaryPool
pub fn pool_id(&self) -> &DynamicBackingPoolId
pub const fn domain_id(&self) -> CapacityDomainId
pub const fn excluded_from_reclaim(&self) -> bool
pub const fn resident_bytes(&self) -> u64
pub const fn pending_growth_bytes(&self) -> u64
pub const fn free_bytes(&self) -> u64
pub const fn largest_contiguous_bytes(&self) -> u64
pub fn free_extent_layout_fingerprint(&self) -> &str
pub const fn logical_used_bytes(&self) -> u64
pub const fn live_occupancy(&self) -> &DynamicPoolLiveOccupancyStatus
pub const fn minimum_resident_bytes(&self) -> u64
pub const fn maximum_resident_bytes(&self) -> u64
pub const fn protected_immediate_bytes(&self) -> u64
pub const fn protected_packing_satisfied(&self) -> bool
pub const fn coherent_runnable_floor_bytes(&self) -> u64
pub const fn resident_floor_bytes(&self) -> u64
pub const fn reclaimable_bytes(&self) -> u64
pub fn chunks(&self) -> &[DynamicPoolMaintenanceBoundaryChunk]