pub struct EventBatchEmissionPermit { /* private fields */ }Expand description
Owned capability created only after the emitter has validated an ordered event batch against one transactional cursor.
Implementations
Sourceimpl EventBatchEmissionPermit
impl EventBatchEmissionPermit
pub fn events(&self) -> &[ExecutionEvent]
pub fn into_events(self) -> Vec<ExecutionEvent>