pub struct ExecutionBatchParticipants<R>where
R: DeviceRuntime,{ /* private fields */ }Expand description
Canonical non-empty set selected by the scheduler for one continuous batch. Membership is exact; capacity shapes may not claim a different sequence count and no global concurrency ceiling is embedded here.
Implementations
Sourceimpl<R> ExecutionBatchParticipants<R>where
R: DeviceRuntime,
impl<R> ExecutionBatchParticipants<R>where
R: DeviceRuntime,
pub fn new(sessions: Vec<Arc<SequenceSession<R>>>) -> Result<Self, VNextError>
pub fn len(&self) -> u32
pub fn is_empty(&self) -> bool
pub fn sessions(&self) -> &[Arc<SequenceSession<R>>]
pub fn plan_evidence(&self) -> &TrustedPlanRuntimeEvidence
pub fn bind_work_shape( &self, token_spans: Vec<TokenSpanWork>, ) -> Result<BatchWorkShape, VNextError>
Sourceimpl<R> ExecutionBatchParticipants<R>where
R: DeviceRuntime,
impl<R> ExecutionBatchParticipants<R>where
R: DeviceRuntime,
pub fn try_begin_step( &self, request: StepResourceAdmissionRequest, lane: &Arc<ExecutionLane<R>>, ) -> Result<StepResourceAdmissionDecision<R>, VNextError>
pub fn try_begin_step_profiled<F>( &self, request: StepResourceAdmissionRequest, lane: &Arc<ExecutionLane<R>>, observer: F, ) -> Result<StepResourceAdmissionDecision<R>, VNextError>