pub struct OperationOracleRegistry { /* private fields */ }Expand description
Trusted concrete registry that owns contracts and exact oracle objects for the lifetime of every bound invocation handle.
Implementations
Sourceimpl OperationOracleRegistry
impl OperationOracleRegistry
pub fn new( catalog: &CapabilityCatalog, contracts: Vec<Box<dyn OperationContract>>, registrations: Vec<OperationOracleRegistration>, ) -> Result<Self, VNextError>
pub fn catalog_fingerprint(&self) -> &str
pub fn contract( &self, operation_id: &OperationId, ) -> Result<&dyn OperationContract, VNextError>
pub fn bind<'registry>( &'registry self, operation_id: &OperationId, ) -> Result<BoundOperationOracle<'registry>, VNextError>