pub struct OperationPlanningHandle<'registry> { /* private fields */ }Expand description
Planning view issued only by a concrete runtime registry. Holding this view proves that node resolution used the same composition root that can later bind the selected runtime provider.