pub struct PlanCapacityWaitRegistration<R>where
R: DeviceRuntime,{ /* private fields */ }Expand description
A capacity wait registration that keeps its exact plan runtime alive until the waiter either observes a retry epoch or is cancelled by being dropped.
Implementations
Sourceimpl<R> PlanCapacityWaitRegistration<R>where
R: DeviceRuntime,
impl<R> PlanCapacityWaitRegistration<R>where
R: DeviceRuntime,
pub fn recheck(&self) -> Result<CapacityWaitRecheck, VNextError>
pub async fn wait_for_change(self) -> Result<CapacityEpochs, VNextError>