pub struct PlanExactAlias { /* private fields */ }Expand description
Core-proven exact storage equality between one output and its declared input. A MayAlias contract with distinct storage deliberately emits no edge.
Implementations
Sourceimpl PlanExactAlias
impl PlanExactAlias
pub fn output_value_id(&self) -> &ProgramValueId
pub const fn output_ordinal(&self) -> u32
pub fn input_value_id(&self) -> &ProgramValueId
pub const fn input_ordinal(&self) -> u32
pub const fn kind(&self) -> PlanExactAliasKind