pub struct ProviderCheckpointStatePort { /* private fields */ }Expand description
A declaration is specific to an operation port and physical storage ABI. Its ordinal is validated against the selected operation; it is not a semantic state name or a user-supplied resource byte range.
Implementations
Sourceimpl ProviderCheckpointStatePort
impl ProviderCheckpointStatePort
pub const fn new( role: ResolvedValueRole, ordinal: u32, storage_profile: DynamicStorageProfile, layout: ProviderCheckpointStateLayout, ) -> Self
pub const fn role(&self) -> ResolvedValueRole
pub const fn ordinal(&self) -> u32
pub const fn storage_profile(&self) -> DynamicStorageProfile
pub const fn layout(&self) -> ProviderCheckpointStateLayout