pub struct ResolvedValueBinding { /* private fields */ }Expand description
Value/resource binding shared by the execution plan and provider invocation. Keeping one representation prevents a lossy translation at the runtime boundary.
Implementations
Sourceimpl ResolvedValueBinding
impl ResolvedValueBinding
pub fn new( value_id: ProgramValueId, role: ResolvedValueRole, ordinal: u32, tensor: ResolvedTensorSpec, access: TensorAccess, alias: AliasPolicy, usage: BufferUsage, weight: Option<ResolvedWeightBinding>, storage: ResolvedValueStorage, ) -> Result<Self, VNextError>
pub fn value_id(&self) -> &ProgramValueId
pub fn role(&self) -> ResolvedValueRole
pub fn ordinal(&self) -> u32
pub fn tensor(&self) -> &ResolvedTensorSpec
pub fn access(&self) -> TensorAccess
pub fn alias(&self) -> &AliasPolicy
pub const fn usage(&self) -> BufferUsage
pub fn weight(&self) -> Option<&ResolvedWeightBinding>
pub fn storage(&self) -> &ResolvedValueStorage