pub struct ResourcePoolId(/* private fields */);Expand description
Process-local identity of one provisioned resource pool. It is independent from both the request that provisioned the pool and requests that later use one of its active-sequence slots.
Implementations