pub struct SequenceSynchronizationFailure<'resources, 'exec, R>where
R: DeviceRuntime,{ /* private fields */ }Expand description
Retry owner for a failed stream drain. It intentionally does not expose the active dispatch permit, so no operation can be submitted between a failed synchronization attempt and its retry.
Implementations
Sourceimpl<'resources, 'exec, R> SequenceSynchronizationFailure<'resources, 'exec, R>where
R: DeviceRuntime,
impl<'resources, 'exec, R> SequenceSynchronizationFailure<'resources, 'exec, R>where
R: DeviceRuntime,
pub fn error(&self) -> &SequenceSynchronizationError<R::Error>
pub fn retry( self, ) -> Result<SynchronizedSequencePermit<'resources, 'exec, R>, SequenceSynchronizationFailure<'resources, 'exec, R>>