pub struct SubmissionWaveDeterminismPhysicalReadback { /* private fields */ }Expand description
One physical readback buffer retained once even when multiple semantic witnesses intentionally project onto the same bytes.
Implementations
Sourceimpl SubmissionWaveDeterminismPhysicalReadback
impl SubmissionWaveDeterminismPhysicalReadback
pub fn request(&self) -> &CompletionReadbackRequest
pub fn raw_sha256(&self) -> &str
pub fn bytes(&self) -> &[u8] ⓘ