pub struct WeightSchema {
pub format_id: WeightFormatId,
pub layout_id: WeightLayoutId,
pub version: ContractVersion,
pub components: Vec<WeightComponentSpec>,
pub tensors: Vec<WeightTensorSpec>,
}Fields
format_id: WeightFormatIdlayout_id: WeightLayoutIdversion: ContractVersioncomponents: Vec<WeightComponentSpec>tensors: Vec<WeightTensorSpec>Implementations
Sourceimpl WeightSchema
impl WeightSchema
pub fn validate(&self, family_id: &ModelFamilyId) -> Result<(), VNextError>
pub fn fingerprint(&self) -> Result<String, VNextError>
pub fn quantization_formats(&self) -> BTreeSet<QuantizationFormatId>
pub fn tensor(&self, weight_id: &WeightId) -> Option<&WeightTensorSpec>
Sourcepub fn physical_component_refs(
&self,
weight_id: &WeightId,
) -> Result<Vec<&WeightComponentSpec>, VNextError>
pub fn physical_component_refs( &self, weight_id: &WeightId, ) -> Result<Vec<&WeightComponentSpec>, VNextError>
Ordered physical components needed to materialize one logical value. The order is the schema’s component order and is therefore stable for fingerprints and resource-plan evidence.
pub fn physical_bytes(&self, weight_id: &WeightId) -> Result<u64, VNextError>
pub fn physical_resource_requirements( &self, weight_id: &WeightId, ) -> Result<Vec<PhysicalWeightComponentRef>, VNextError>
Sourceimpl WeightSchema
impl WeightSchema
pub fn validate_program_references( &self, family_id: &ModelFamilyId, program: &ModelProgram, ) -> Result<(), VNextError>