pub struct DeviceBufferRetention { /* private fields */ }Expand description
Opaque core ownership retained by backend commands that outlive the borrowed buffer view used to encode them. Backends may clone and store this value, but cannot inspect or manufacture resource ownership.
Implementations
Sourceimpl DeviceBufferRetention
impl DeviceBufferRetention
pub const fn reusable_address_scope(&self) -> Option<DeviceReusableAddressScope>