pub struct DynamicBackingDeferred { /* private fields */ }Implementations
Sourceimpl DynamicBackingDeferred
impl DynamicBackingDeferred
pub fn blockers(&self) -> &[DynamicBackingBlocker]
pub const fn release_epoch(&self) -> u64
pub const fn capacity_epoch(&self) -> u64
pub const fn epochs(&self) -> CapacityEpochs
pub fn wait_condition(&self) -> &CapacityWaitCondition
pub const fn scope(&self) -> DynamicBackingClaimScope
pub const fn lifetime(&self) -> Option<AllocationLifetime>
Sourcepub fn protected_immediate(&self) -> &CapacityVector
pub fn protected_immediate(&self) -> &CapacityVector
Exact uncommitted physical demand that must remain simultaneously runnable while maintenance rebalances other pools.
Sourcepub fn protected_packing_envelopes(&self) -> &[DynamicBackingPackingEnvelope]
pub fn protected_packing_envelopes(&self) -> &[DynamicBackingPackingEnvelope]
Exact per-pool physical claim shapes that must remain packable while maintenance rebalances unreferenced chunks for this deferred bundle.