pub struct LogicalCheckpointLease { /* private fields */ }Expand description
A checkpoint’s independent domain claim. This lease has no request or sequence parent and confers no device allocation or execution authority.
The resource owner must release its physical extents before this logical lease. A completion fence may retain that owner after cache eviction.
Implementations
Sourceimpl LogicalCheckpointLease
impl LogicalCheckpointLease
pub fn coordinator_id(&self) -> LogicalAdmissionCoordinatorId
pub fn claims(&self) -> &CapacityVector
Sourcepub const fn retained_bytes(&self) -> u64
pub const fn retained_bytes(&self) -> u64
Independently retained aligned extents, not another device allocation.