pub struct MemoryPlan { /* private fields */ }Implementations
Sourceimpl MemoryPlan
impl MemoryPlan
pub const fn device_capacity_bytes(&self) -> u64
pub const fn policy_capacity_bytes(&self) -> u64
pub const fn reserve_bytes(&self) -> u64
pub const fn usable_capacity_bytes(&self) -> u64
pub const fn maximum_active_sequences(&self) -> u32
pub const fn capacity_bytes(&self) -> u64
pub const fn static_bytes(&self) -> u64
pub const fn minimum_request_bytes(&self) -> u64
pub const fn minimum_sequence_bytes(&self) -> u64
pub const fn minimum_step_bytes(&self) -> u64
pub const fn minimum_invocation_peak_bytes(&self) -> u64
pub const fn minimum_runnable_request_bytes(&self) -> u64
pub const fn invocation_liveness_mode(&self) -> InvocationLivenessMode
pub fn invocation_liveness(&self) -> &[InvocationResourceLiveness]
Sourcepub fn theoretical_ceiling_bytes(&self) -> u128
pub fn theoretical_ceiling_bytes(&self) -> u128
Conservative checked evidence across static allocations, live provider formula maxima, reusable execution workspace, and the protocol ceiling. It is never itself a reservation, admission target, or performance claim.
pub fn static_allocations(&self) -> &[ResourceAllocation]
pub fn dynamic_descriptors(&self) -> &[DynamicResourceDescriptor]
pub fn dynamic_pools(&self) -> &[DynamicBackingPoolSpec]
pub fn reusable_execution(&self) -> Option<&ReusableExecutionMemoryPlan>
pub fn static_buffer_requests(&self) -> Result<Vec<BufferRequest>, VNextError>