pub struct ProviderResourcePlan { /* private fields */ }Expand description
Trusted output from the selected provider’s shape/attribute-specific resource estimator. The core binds it to the exact estimator input and selected provider before the values can enter an executable plan.
Implementations
Sourceimpl ProviderResourcePlan
impl ProviderResourcePlan
pub fn provider_id(&self) -> &ProviderId
pub fn estimator_id(&self) -> &str
pub const fn estimator_version(&self) -> ContractVersion
pub fn estimator_implementation_fingerprint(&self) -> &str
pub fn estimator_input_fingerprint(&self) -> &str
pub fn estimate_fingerprint(&self) -> &str
pub const fn value_alignment_bytes(&self) -> u64
pub fn scratch(&self) -> Option<&ProviderWorkspaceRequirement>
pub fn binding(&self) -> Option<&ProviderWorkspaceRequirement>
pub fn persistent(&self) -> Option<&ProviderWorkspaceRequirement>