pub struct SynchronizedSequencePermit<'resources, 'exec, R>where
R: DeviceRuntime,{ /* private fields */ }Expand description
Stream-drained typestate. It has no dispatch API and must choose exactly one terminal slot disposition.
Implementations
Sourceimpl<R> SynchronizedSequencePermit<'_, '_, R>where
R: DeviceRuntime,
impl<R> SynchronizedSequencePermit<'_, '_, R>where
R: DeviceRuntime,
pub fn complete(self) -> Result<ActiveSequenceCompletionReceipt, VNextError>
Sourcepub fn abort(self) -> Result<ActiveSequenceAbortReceipt, VNextError>
pub fn abort(self) -> Result<ActiveSequenceAbortReceipt, VNextError>
Produces abort evidence only after the exact bound stream was drained. Only this exact logical sequence remains poisoned after abort.